@@ -6,7 +6,7 @@ import shutil
 from pathlib import Path
 from .init import create_file
 from configparser import ConfigParser
-import pkg_resources
+import importlib.metadata
 from .copyfile import copy_files
 from .changeapps import create_plugins_apps_py
 
@@ -24,7 +24,7 @@ def plugins(folder: str):
         if exists(plugins_path):
             print('Plugins directory already exists')
         else:
-            if sys.argv[2] in [pkg.key for pkg in pkg_resources.working_set]:
+            if sys.argv[2] in [dist.metadata['Name'] for dist in importlib.metadata.distributions()]:
                 print('Plugins directory already exists')
             else:
                 os.makedirs(plugins_path)
@@ -48,11 +48,6 @@ def plugins(folder: str):
 
                 create_file('')
 
-                setup_config = ConfigParser()
-                setup_config.read(join(join(getcwd()), 'setup.ini'), encoding='utf-8')
-                setup_config.set('project', 'name', folder)
-                setup_config.write(open(join(join(getcwd()), 'setup.ini'), "wt"))
-
                 copy_files(join(current_path.parent, 'extends'), plugins_path)
 
                 apps_path = join(plugins_path, 'apps.py')
