@@ -1,11 +1,11 @@
-from os.path import join, exists, isfile, isdir
-from os import makedirs, getcwd, listdir
+from os.path import join, exists
+from os import makedirs, getcwd
 import os
 import sys
 import shutil
 from pathlib import Path
 from .init import create_file
-import pkg_resources
+import importlib.metadata
 from configparser import ConfigParser
 from .copyfile import copy_files
 
@@ -23,7 +23,7 @@ def project(folder: str):
         if exists(project_path):
             print('Project directory already exists')
         else:
-            if sys.argv[2] in [pkg.key for pkg in pkg_resources.working_set]:
+            if sys.argv[2] in [dist.metadata['Name'] for dist in importlib.metadata.distributions()]:
                 print('Project directory already exists')
             else:
                 makedirs(project_path)
@@ -41,7 +41,11 @@ def project(folder: str):
                 f.close()
 
                 shutil.copy2(join(file_path, 'bomiotconf.ini'), project_path)
-                shutil.copy2(join(file_path, 'websocket.py'), project_path)
+                shutil.copy2(join(file_path, 'receiver.py'), project_path)
+                shutil.copy2(join(file_path, 'files.py'), project_path)
+                shutil.copy2(join(file_path, 'server.py'), project_path)
+                copy_files(join(file_path, 'fastapi_app'), join(project_path, 'fastapi_app'))
+                copy_files(join(file_path, 'flask_app'), join(project_path, 'flask_app'))
 
                 create_file(str(sys.argv[2]))
 
@@ -50,6 +54,8 @@ def project(folder: str):
                 setup_config.set('project', 'name', folder)
                 setup_config.write(open(join(join(getcwd()), 'setup.ini'), "wt"))
 
+                copy_files(join(join(current_path.parent.parent, 'server'), 'media'), join(project_path, 'media'))
+                copy_files(join(join(current_path.parent.parent, 'server'), 'language'), join(project_path, 'language'))
                 copy_files(join(current_path.parent.parent, 'templates'), join(project_path, 'templates'))
-
+                
                 print(f'Initialized project workspace {sys.argv[2]}')
\ No newline at end of file
