@@ -3,29 +3,31 @@ from django.core.management.utils import get_random_secret_key
 import os
 import sys
 from configparser import ConfigParser
-import pkg_resources
-from .pkgcheck import pkg_check, cwd_check, ignore_pkg, ignore_cwd
+import importlib.metadata
+import bomiot
+from bomiot.server.server.pkgcheck import pkg_check, cwd_check, ignore_pkg, ignore_cwd
 import importlib.util
 from os import listdir
 from os.path import join, isdir, exists, isfile
 
 
-BASE_DIR = Path(__file__).resolve().parent.parent
+BASE_DIR = join(Path(bomiot.__file__).resolve().parent, 'server')
 
-
-CONFIG = ConfigParser()
 WORKING_SPACE_CONFIG = ConfigParser()
 WORKING_SPACE_CONFIG.read(join(BASE_DIR, 'workspace.ini'), encoding='utf-8')
 WORKING_SPACE = WORKING_SPACE_CONFIG.get('space', 'name', fallback='Create your working space first')
 sys.path.insert(0, WORKING_SPACE)
-CONFIG.read(join(WORKING_SPACE, 'setup.ini'), encoding='utf-8')
+
+CONFIG = ConfigParser()
+setup_ini_path = join(WORKING_SPACE, 'setup.ini')
+CONFIG.read(setup_ini_path, encoding='utf-8')
 PROJECT_NAME = CONFIG.get('project', 'name', fallback='bomiot')
 
 SECRET_KEY = get_random_secret_key()
 
 DEBUG = True
 
-ALLOWED_HOSTS = ['*']
+ALLOWED_HOSTS = ['*', '127.0.0.1', 'localhost']
 AUTH_USER_MODEL = "core.User"
 
 INSTALLED_APPS = [
@@ -42,8 +44,8 @@ INSTALLED_APPS = [
     'bomiot.server.core',
 ]
 
-
-res_pkg_list = list(set([pkg.key for pkg in pkg_resources.working_set]).difference(set(ignore_pkg())))
+all_packages = [dist.metadata['Name'] for dist in importlib.metadata.distributions()]
+res_pkg_list = list(set([name.lower() for name in all_packages]).difference(set(ignore_pkg())))
 pkg_squared = list(map(lambda data: pkg_check(data), res_pkg_list))
 filtered_pkg_squared = list(filter(lambda x: x is not None, pkg_squared))
 
@@ -51,59 +53,93 @@ current_path = list(set([p for p in listdir(WORKING_SPACE) if isdir(p)]).differe
 cur_squared = list(map(lambda data: cwd_check(data), current_path))
 filtered_current_path = list(filter(lambda y: y is not None, cur_squared))
 
-LOCALE_PATHS = []
+def load_dynamic_apps() -> None:
+    global INSTALLED_APPS
+    load_apps_from_project()
+    load_apps_from_working_space()
+    load_apps_from_packages()
+    
 
-if len(filtered_pkg_squared) > 0:
-    for module in filtered_pkg_squared:
-        module_path = importlib.util.find_spec(PROJECT_NAME).origin
-        list_module_path = Path(module_path).resolve().parent
-        pkg_config_check = ConfigParser()
-        pkg_config_check.read(join(list_module_path), 'bomiotconf.ini', encoding='utf-8')
-        LOCALE_PATHS.append(join(list_module_path, 'locale'))
-        app_mode = pkg_config_check.get('mode', 'name', fallback='plugins')
-        if app_mode == 'plugins':
-            try:
-                if isfile(join(list_module_path, 'apps.py')):
-                    if module not in INSTALLED_APPS:
-                        INSTALLED_APPS.append(f'{module}')
-            except:
+def load_apps_from_packages() -> None:
+    global INSTALLED_APPS
+    all_packages = [dist.metadata['Name'] for dist in importlib.metadata.distributions()]
+    res_pkg_list = list(set([name.lower() for name in all_packages]).difference(set(ignore_pkg())))
+    for module in res_pkg_list:
+        spec = importlib.util.find_spec(module)
+        if not spec:
+            continue
+        module_path = spec.origin
+        if not module_path:
+            continue
+        module_dir = Path(module_path).resolve().parent
+        config_path = join(module_dir, 'bomiotconf.ini')
+        pkg_config = ConfigParser()
+        if pkg_config.read(config_path, encoding='utf-8'):
+            app_mode = pkg_config.get('mode', 'name', fallback='plugins')
+            if app_mode == 'plugins':
+                apps_py_path = join(module_dir, 'apps.py')
+                if isfile(apps_py_path):
+                    app_name = module
+                    if app_name not in INSTALLED_APPS:
+                        INSTALLED_APPS.append(app_name)
+                    else:
+                        continue
+                else:
+                    continue
+            else:
                 continue
-        elif app_mode == 'project':
-            if module == PROJECT_NAME:
-                for app in listdir(list_module_path):
-                    try:
-                        if isfile(join(join(list_module_path, app), 'apps.py')):
-                            if app not in INSTALLED_APPS:
-                                INSTALLED_APPS.append(f'{app}')
-                    except:
-                        pass
+        else:
+            continue
 
-if len(filtered_current_path) > 0:
-    for module_name in filtered_current_path:
+def load_apps_from_working_space() -> None:
+    global INSTALLED_APPS
+    current_path = [
+        p for p in listdir(WORKING_SPACE) 
+        if isdir(join(WORKING_SPACE, p)) and p not in ignore_cwd()
+    ]
+    for module_name in current_path:
+        module_dir = join(WORKING_SPACE, module_name)
+        config_path = join(module_dir, 'bomiotconf.ini')
         app_mode_config = ConfigParser()
-        app_mode_config.read(join(join(WORKING_SPACE, module_name), 'bomiotconf.ini'), encoding='utf-8')
-        LOCALE_PATHS.append(join(join(WORKING_SPACE, module_name), 'locale'))
+        if not app_mode_config.read(config_path, encoding='utf-8'):
+            continue
         app_mode = app_mode_config.get('mode', 'name')
         if app_mode == 'plugins':
-            try:
-                if isfile(join(join(WORKING_SPACE, module_name), 'apps.py')):
-                    if module_name not in INSTALLED_APPS:
-                        INSTALLED_APPS.append(module_name)
-            except:
+            apps_py_path = join(module_dir, 'apps.py')
+            if isfile(apps_py_path):
+                if module_name not in INSTALLED_APPS:
+                    INSTALLED_APPS.append(module_name)
+                else:
+                    continue
+            else:
                 continue
-        elif app_mode == 'project':
-            if module_name == PROJECT_NAME:
-                project_path = join(WORKING_SPACE, PROJECT_NAME)
-                for app in listdir(project_path):
-                    try:
-                        if isfile(join(join(project_path, app), 'apps.py')):
-                            if f'{PROJECT_NAME}.{app}' not in INSTALLED_APPS:
-                                INSTALLED_APPS.append(f'{PROJECT_NAME}.{app}')
-                    except:
-                        pass
+        else:
+            continue
 
+def load_apps_from_project() -> None:
+    global INSTALLED_APPS, PROJECT_NAME
+    if not PROJECT_NAME or PROJECT_NAME not in [p for p in listdir(WORKING_SPACE) if isdir(p)]:
+        return
+    project_path = join(WORKING_SPACE, PROJECT_NAME)
+    app_dirs = [
+        app for app in listdir(project_path) 
+        if isdir(join(project_path, app))
+    ]
+    for app in app_dirs:
+        apps_py_path = join(project_path, app, 'apps.py')
+        if isfile(apps_py_path):
+            app_name = f'{PROJECT_NAME}.{app}'
+            if app_name not in INSTALLED_APPS:
+                INSTALLED_APPS.append(app_name)
+            else:
+                continue
+        else:
+            continue
+
+load_dynamic_apps()
 
 MIDDLEWARE = [
+    'django.middleware.gzip.GZipMiddleware',
     'django.middleware.security.SecurityMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.locale.LocaleMiddleware',
@@ -113,15 +149,12 @@ MIDDLEWARE = [
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
     # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
+    'bomiot.server.core.middlewares.DisableMediaCachingMiddleware'
 ]
 
 ROOT_URLCONF = 'bomiot.server.server.urls'
 
-TEMPLATES_PATH = join(BASE_DIR.parent, 'templates')
-
-if PROJECT_NAME in [p for p in listdir(WORKING_SPACE) if isdir(p)]:
-    TEMPLATES_PATH = join(join(WORKING_SPACE, PROJECT_NAME), 'templates')
-
+TEMPLATES_PATH = join(WORKING_SPACE, PROJECT_NAME)
 
 TEMPLATES = [
     {
@@ -163,11 +196,26 @@ if db_engine == 'sqlite':
         'default': {
             'ENGINE': 'django.db.backends.sqlite3',
             'NAME': DB_PATH,
+            'CONN_MAX_AGE': 60,
             'OPTIONS': {
-                'timeout': 20,
+                'timeout': 60,
             }
         }
     }
+elif db_engine == 'mysql':
+    DATABASES = {
+        'default': {
+            'ENGINE': DATABASE_MAP[CONFIG['database']['engine']],
+            'NAME': CONFIG['database']['name'],
+            'USER': CONFIG['database']['user'],
+            'PASSWORD': CONFIG['database']['password'],
+            'HOST': CONFIG['database']['host'],
+            'PORT': CONFIG['database']['port'],
+            'OPTIONS': {
+                'charset': 'utf8mb4',
+            },
+        }
+    }
 else:
     DATABASES = {
         'default': {
@@ -203,14 +251,18 @@ AUTH_PASSWORD_VALIDATORS = [
 
 # Internationalization
 # https://docs.djangoproject.com/en/4.2/topics/i18n/
-
-LANGUAGE_CODE = CONFIG.getint('local', 'language_code', fallback='en')
+if PROJECT_NAME == 'bomiot':
+    LANGUAGE_DIR = join(BASE_DIR, 'language').replace('\\', '/')
+else:
+    LANGUAGE_DIR = join(join(WORKING_SPACE, PROJECT_NAME), 'language').replace('\\', '/')
+if exists(join(WORKING_SPACE, PROJECT_NAME)):
+    exists(LANGUAGE_DIR) or os.makedirs(LANGUAGE_DIR)
 
 TIME_ZONE = CONFIG.getint('local', 'time_zone', fallback='UTC')
 
 USE_I18N = True
 
-USE_L10N = True  # 开启本地化(localization)
+USE_L10N = True  # (localization)
 
 USE_TZ = False
 
@@ -231,8 +283,12 @@ else:
     ]
 
 MEDIA_URL = 'media/'
-MEDIA_ROOT = join(WORKING_SPACE, 'media').replace('\\', '/')
-exists(MEDIA_ROOT) or os.makedirs(MEDIA_ROOT)
+if PROJECT_NAME == 'bomiot':
+    MEDIA_ROOT = join(BASE_DIR, 'media').replace('\\', '/')
+else:
+    MEDIA_ROOT = join(join(WORKING_SPACE, PROJECT_NAME), 'media').replace('\\', '/')
+if exists(join(WORKING_SPACE, PROJECT_NAME)):
+    exists(MEDIA_ROOT) or os.makedirs(MEDIA_ROOT)
 
 
 # Default primary key field type
@@ -272,6 +328,10 @@ CORS_ALLOW_HEADERS = (
     'event-sign'
 )
 
+CORS_EXPOSE_HEADERS = [
+    "expire"
+]
+
 X_FRAME_OPTIONS = 'SAMEORIGIN'
 
 
@@ -305,7 +365,7 @@ LOGGING = {
             "class": "logging.handlers.RotatingFileHandler",
             "filename": SERVER_LOGS_FILE,
             "maxBytes": 1024 * 1024 * 100,  # 100 MB
-            "backupCount": 5,  # 最多备份5个
+            "backupCount": 5,
             "formatter": "standard",
             "encoding": "utf-8",
         },
@@ -314,7 +374,7 @@ LOGGING = {
             "class": "logging.handlers.RotatingFileHandler",
             "filename": ERROR_LOGS_FILE,
             "maxBytes": 1024 * 1024 * 100,  # 100 MB
-            "backupCount": 3,  # 最多备份3个
+            "backupCount": 3,
             "formatter": "standard",
             "encoding": "utf-8",
         },
@@ -330,6 +390,11 @@ LOGGING = {
             "handlers": ["console", "error", "file"],
             "level": "INFO",
         },
+        'apscheduler': {
+            'handlers': ['console'],
+            'level': 'WARNING',
+            'propagate': False,
+        },
         "django": {
             "handlers": ["console", "error", "file"],
             "level": "INFO",
@@ -339,20 +404,12 @@ LOGGING = {
             'handlers': ["console", "error", "file"],
             'propagate': False,
             'level': "INFO"
-        },
-        "uvicorn.error": {
-            "level": "INFO",
-            "handlers": ["console", "error", "file"],
-        },
-        "uvicorn.access": {
-            "handlers": ["console", "error", "file"],
-            "level": "INFO"
-        },
+        }
     },
 }
 
 REST_FRAMEWORK = {
-    # AttributeError: ‘AutoSchema’ object has no attribute ‘get_link’
+    # AttributeError: 'AutoSchema' object has no attribute 'get_link'
     # DEFAULT SET:
     'DEFAULT_SCHEMA_CLASS': 'rest_framework.schemas.openapi.AutoSchema',
     # EXCEPTION:
@@ -422,103 +479,57 @@ REST_FRAMEWORK = {
     },
 }
 
+CACHES = {
+    "default": {
+        "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
+        "LOCATION": "unique-snowflake",
+    }
+}
+
 INTERNAL_IPS = [
     '127.0.0.1',
     'localhost'
 ]
 
 USER_JWT_TIME = CONFIG.getint('jwt', 'user_jwt_time', fallback=1000000)
+JWT_SALT = 'ds()udsjo@jlsdosjf)wjd_#(#)$'
+
+KEY_PATH = join(WORKING_SPACE, 'auth_key.py')
+KEY = ''
+if exists(KEY_PATH):
+    try:
+        with open(KEY_PATH, 'r', encoding='utf-8') as f:
+            content = f.read()
+        lines = content.split('\n')
+        for line in lines:
+            line = line.strip()
+            if line.startswith('KEY') and '=' in line:
+                key_value = line.split('=', 1)[1].strip()
+                if key_value.startswith("'") and key_value.endswith("'"):
+                    key_value = key_value[1:-1]
+                elif key_value.startswith('"') and key_value.endswith('"'):
+                    key_value = key_value[1:-1]
+                KEY = key_value
+                break
+    except Exception as e:
+        print(f"Error reading auth_key.py: {e}")
+        KEY = ''
 
 ALLOCATION_SECONDS = CONFIG.getint('throttle', 'allocation_seconds', fallback=1)
 THROTTLE_SECONDS = CONFIG.getint('throttle', 'throttle_seconds', fallback=10)
 
-ALLOWED_IMG = CONFIG.get('image_upload', 'suffix_name', fallback='jpg, jpeg, gif, png, bmp, webp').split(',')
+REQUEST_LIMIT = CONFIG.getint('request', 'limit', fallback=2)
 
 DATA_UPLOAD_MAX_MEMORY_SIZE = None
 
+FILE_SIZE = CONFIG.getint('file', 'file_size', fallback=102400000)
+FILE_EXTENSION = CONFIG.get('file', 'file_extension', fallback='py,png,jpg,jpeg,gif,bmp,webp,txt,md,html,htm,js,css,json,xml,csv,xlsx,xls,ppt,pptx,doc,docx,pdf').replace(" ", "").split(',')
 
-
-LANGUAGES = (
-    ('af', 'Afrikaans'),
-    ('ar', 'Arabic'),
-    ('ast', 'Asturian'),
-    ('az', 'Azerbaijani'),
-    ('bg', 'Bulgarian'),
-    ('be', 'Belarusian'),
-    ('bn', 'Bengali'),
-    ('br', 'Breton'),
-    ('bs', 'Bosnian'),
-    ('ca', 'Catalan'),
-    ('cs', 'Czech'),
-    ('cy', 'Welsh'),
-    ('da', 'Danish'),
-    ('de', 'German'),
-    ('dsb', 'Lower Sorbian'),
-    ('el', 'Greek'),
-    ('en', 'English'),
-    ('en-gb', 'British English'),
-    ('eo', 'Esperanto'),
-    ('es', 'Spanish'),
-    ('es-ar', 'Argentinian Spanish'),
-    ('et', 'Estonian'),
-    ('eu', 'Basque'),
-    ('fa', 'Persian'),
-    ('fi', 'Finnish'),
-    ('fr', 'French'),
-    ('fy', 'Frisian'),
-    ('ga', 'Irish'),
-    ('gd', 'Scottish Gaelic'),
-    ('gl', 'Galician'),
-    ('he', 'Hebrew'),
-    ('hi', 'Hindi'),
-    ('hr', 'Croatian'),
-    ('hsb', 'Upper Sorbian'),
-    ('hu', 'Hungarian'),
-    ('hy', 'Armenian'),
-    ('ia', 'Interlingua'),
-    ('id', 'Indonesian'),
-    ('is', 'Icelandic'),
-    ('it', 'Italian'),
-    ('ja', 'Japanese'),
-    ('ka', 'Georgian'),
-    ('kk', 'Kazakh'),
-    ('km', 'Khmer'),
-    ('kn', 'Kannada'),
-    ('ko', 'Korean'),
-    ('lb', 'Luxembourgish'),
-    ('lt', 'Lithuanian'),
-    ('lv', 'Latvian'),
-    ('mk', 'Macedonian'),
-    ('ml', 'Malayalam'),
-    ('mn', 'Mongolian'),
-    ('my', 'Burmese'),
-    ('nb', 'Norwegian Bokmal'),
-    ('ne', 'Nepali'),
-    ('nl', 'Dutch'),
-    ('nn', 'Norwegian Nynorsk'),
-    ('os', 'Ossetic'),
-    ('pa', 'Punjabi'),
-    ('pl', 'Polish'),
-    ('pt', 'Portuguese'),
-    ('pt-br', 'Brazilian Portuguese'),
-    ('ro', 'Romanian'),
-    ('ru', 'Russian'),
-    ('sk', 'Slovak'),
-    ('sl', 'Slovenian'),
-    ('sq', 'Albanian'),
-    ('sr', 'Serbian'),
-    ('sr-latn', 'Serbian Latin'),
-    ('sv', 'Swedish'),
-    ('sw', 'Swahili'),
-    ('ta', 'Tamil'),
-    ('te', 'Telugu'),
-    ('th', 'Thai'),
-    ('tr', 'Turkish'),
-    ('tt', 'Tatarish'),
-    ('udm', 'Udmurt'),
-    ('uk', 'Ukrainian'),
-    ('ur', 'Urdu'),
-    ('vi', 'Vietnamese'),
-    ('zh-hans', 'Simplified Chinese'),
-    ('zh-hant', 'Traditional Chinese'),
-)
\ No newline at end of file
+EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
+EMAIL_HOST = CONFIG.get('mail', 'email_host', fallback='')
+EMAIL_PORT = CONFIG.getint('mail', 'email_port', fallback=465)
+EMAIL_HOST_USER = CONFIG.get('mail', 'email_host_user', fallback='')
+EMAIL_HOST_PASSWORD = CONFIG.get('mail', 'email_host_password', fallback='')
+DEFAULT_FROM_EMAIL = CONFIG.get('mail', 'default_from_email', fallback='')
+EMAIL_FROM = CONFIG.get('mail', 'email_from', fallback='')
+EMAIL_USE_SSL = CONFIG.getboolean('mail', 'email_use_ssl', fallback=True)
\ No newline at end of file
