@@ -26,5 +26,15 @@ export default route(function (/* { store, ssrContext } */) {
     history: createHistory(process.env.VUE_ROUTER_BASE)
   })
 
+  Router.beforeEach((to, from, next) => {
+  if (to.meta) {
+    next(vm => {
+      vm.$router.replace(to.path);
+    });
+  } else {
+    next();
+  }
+});
+
   return Router
 })
