@@ -31,6 +31,15 @@ export const useTokenStore = defineStore('token', {
           this.token = ''
         }
       }
+    },
+    userPermissionGet (e) {
+      if (this.token !== '') {
+        let strings = this.token.split(".")
+        var userinfo = JSON.parse(decodeURIComponent(escape(window.atob(strings[1].replace(/-/g, "+").replace(/_/g, "/")))));
+        return e in userinfo.permission;
+      } else {
+        return false
+      }
     }
   },
   persist: {
